# Examples

In this folder, you will find the source code used in the examples from the [documentation](https://orion.readthedocs.io/en/develop/index.html). The scripts are ready to be used with Oríon right-away. Use them as inspiration for your projects or copy them directly into your development environment! 

Each folder corresponds to one example. Feel free to add some of your own!